@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001000';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001001';
 #pod =encoding UTF-8
 #pod  
 #pod =head1 SYNOPSIS
@@ -54,10 +54,6 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001000';
 #pod 	[AutoPrereqs]
 #pod 	[Prereqs::AuthorDeps]
 #pod 	[PrereqsClean]
-#pod 	[Prereqs::MatchInstalled::All]
-#pod 	exclude = strict
-#pod 	exclude = warnings
-#pod 	exclude = Dist::Zilla::PluginBundle::Author::MAXHQ
 #pod
 #pod 	[Prereqs / MAXHQ]
 #pod 	-phase = build
@@ -193,9 +189,6 @@ sub configure {
 		'Prereqs::AuthorDeps',            # "adds Dist::Zilla and the result of "dzil
 		                                  # authordeps" to the 'develop' phase prerequisite list"
 		'PrereqsClean',                   # "Cleans up mess from other Prereq modules"
-		['Prereqs::MatchInstalled::All' => { # adjust prereqs to use same version as currently installed
-			exclude => [qw( strict warnings Dist::Zilla::PluginBundle::Author::MAXHQ )]
-		}],
 		['Prereqs', 'MAXHQ', {            # special prerequisites (name MAXHQ 
 			'-phase' => 'runtime',        # disambiguates the Prereqs plugin in
 			'-relationship' => 'requires',# case it's also specified in users' dist.ini)
@@ -252,7 +245,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 1.001000
+version 1.001001
 
 =head1 SYNOPSIS
 
@@ -304,10 +297,6 @@ Currently this plugin bundle is equivalent to:
 	[AutoPrereqs]
 	[Prereqs::AuthorDeps]
 	[PrereqsClean]
-	[Prereqs::MatchInstalled::All]
-	exclude = strict
-	exclude = warnings
-	exclude = Dist::Zilla::PluginBundle::Author::MAXHQ
 
 	[Prereqs / MAXHQ]
 	-phase = build
